@@ -113,20 +113,21 @@ def touchselectorentry_dialog():
             lst = list(current_buhtoon[lst_key])
             lst.sort()
             for i in lst:
-                selector.append_text(i)
+                if i:
+                    selector.append_text(i)
         else: # Create the nonexistent field
             current_buhtoon[lst_key] = set()
     dialog.vbox.pack_end(selector, True, True, 0)
-    dialog.set_geometry_hints(selector, min_height=300)
+    dialog.set_geometry_hints(selector, min_height=400) # was 300
     dialog.show_all()
 
     response = dialog.run()
-    text = selector.get_current_text()
+    text = selector.get_current_text() or "" # get_current_text() might return None if nothing filled in, guard against that
     dialog.destroy()
 
     if response != gtk.RESPONSE_OK:
         raise DialogAbortedException('')
-    if current_buhtoon:
+    if current_buhtoon and text:           # don't store empty strings etc.
         current_buhtoon[lst_key].add(text) # Add the new one to the set
     return text
 
